$VAR1 = {
    'de' => {
        'searchhelptopic' => 'Hilfe',
        'execsql'         => 'Sql ausführen',
        'wrong_username_text' =>
          'Der Benutzername muss mindestens 3 Zeichen lange sein und darf nur Ziffern und Buchstaben enthalten.',
        'deleteentry'          => 'Tabelle',
        'pass'                 => 'Passwort',
        'rebuild'              => 'rebuild',
        'answers'              => 'Antworten',
        'host'                 => 'Host',
        'body'                 => 'Erstelle Deine Nachricht',
        'savetranslate'        => 'Übersetzen',
        'search'               => 'Suchen',
        'settings'             => 'Einstellungen',
        'exportoperabookmarks' => 'Opera Lesezeichen exportieren',
        'uploads'              => 'Uploads',
        'city'                 => 'city',
        'show'                 => 'Anzeigen',
        'uploadpath'           => 'Upload path',
        'attribute'            => 'Attribute',
        'rename'               => 'Umbenennen',
        'showusers'            => 'Benutzer',
        'processlist'          => 'Prozesse',
        'mediumint' =>
          '-8,388,608 to 8,388,607 [0 to 16,777,215] Attributes:  AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'userprofile'          => 'Benutzer Profile',
        'trash'                => 'Mülleimer',
        'comment'              => 'Kommentar',
        'wrongpass'            => 'wrongpass',
        'firstname'            => 'Vorname',
        'index_type'           => 'index_type',
        'uploadchmod'          => 'Upload chmod',
        'showchangecurrentdb'  => 'Server',
        'sqlsearch'            => 'Suchen',
        'showtabledetails'     => 'Details',
        'addtranslation'       => 'Neue Übersetzung',
        'insertafter'          => 'Einfügen',
        'connect'              => 'Verbinden',
        'links_pro_page'       => 'Einträge/Seite',
        'back'                 => 'zurück',
        'impressum'            => 'Impressum',
        'navigation'           => 'Navigation',
        'postcode'             => 'Postleitzahl',
        'non_unique'           => 'Nicht Unique',
        'connections_per_hour' => 'Verbindungen/Stunde',
        'addprimarykey'        => 'Primärschlüssel hinzufügen',
        'updates_per_hour'     => 'Updates / Stunde',
        'table'                => 'Tabelle erstellen',
        'showtable'            => 'Tabelle',
        'column_name'          => 'Spalten Name',
        'mailsubject'          => 'Betreff',
        'dropcolumn'           => 'Spalte löschen',
        'timestamp' =>
          '19700101000000 -2037+ Attributes: Global Only(YYYYMMDDhhmmss) Default: Current Date &amp; Time',
        'delete'      => 'Löschen',
        'cookiepath'  => 'Cookie Path',
        'optimize'    => 'Optimieren',
        'export'      => 'Exportieren',
        'gbook'       => 'Gästebuch',
        'cardinality' => 'cardinality',
        'droptable'   => 'Tabellen',
        'text' => '0-65,535 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'showsqleditor'  => 'SQL Ausführen',
        'exportdatabase' => 'Datenbank',
        'regexp'         => 'Regulärer Ausdruck',
        'puplisher'      => 'Anbieter',
        'shownewentry'   => 'Neuer Eintrag',
        'dropdatabase'   => 'Datenbanken',
        'date' =>
          '"1000-01-01" - "9999-12-31" Attributes: Global Only(YYYY-MM-DD) Default: NULL["0000-00-00" if NOT NULL]',
        'name'               => 'Name',
        'field'              => 'Feld',
        'showcreatedatabase' => 'Datenbank',
        'checkformsddfsds'   => 'true',
        'street'             => 'Straße',
        'changeengine'       => 'Engine',
        'newsperpage'        => 'Einträge/Seite',
        'createdatabase'     => 'Neue Datenbank',
        'maxlength'          => 'maximale länge',
        'wrong_captcha_text' => 'Capture falsch',
        'blob' =>
          '0-65,535 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'createindex'         => 'Index erstellen',
        'repair'              => 'Reparieren',
        'indexover'           => 'Index über',
        'next'                => 'Weiter',
        'createtable'         => 'Tabelle',
        'changecurrentdb'     => 'Server',
        'addindex'            => 'Index hinzufügen',
        'addunique'           => 'Unique Index hinzufügen',
        'newfolder'           => 'Neues Verzeichnis',
        'right_database_name' => 'Ok',
        'showdatabases'       => 'Datenbanken',
        'username'            => 'Name',
        'enum' =>
          'Column is exactly 1 of 1-65,535 values Attributes: CHARACTER SET Default: NULL [1st value if NOT NULL]',
        'bookmarks'    => 'Lesezeichen',
        'activates'    => 'Aktiviert',
        'phone'        => 'Telefon',
        'edittreeview' => 'Bearbeiten',
        'profile'      => 'Profile',
        'year' => '1900 - 2155 Attributes: Global Only(YYYY) Default: NULL["0000" if NOT NULL]',
        'sort' => 'Sortieren',
        'repairtable'      => 'Reparieren',
        'newTreeViewEntry' => 'Leszeichen',
        'editindex'        => 'Index bearbeiten',
        'rows'             => 'Zeilen',
        'after'            => 'nach',
        'user'             => 'Benutzer',
        'rights'           => 'Rechte',
        'varbinary' =>
          '0-65,535 bytesM=0-255 v5.0.3 Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'news_pro_page'           => 'Einträge/Seite',
        'make'                    => 'Erstellen',
        'daten'                   => 'Daten',
        'packed'                  => 'packed',
        'properties'              => 'Einstellungen',
        'chars'                   => 'Zeichen',
        'renametable'             => 'Tabelle umbenennen',
        'codenotcheckedfileerror' => '',
        'speichern'               => 'Speichern',
        'saverights'              => 'Rechte',
        'tinytext' =>
          '0-255 Characters Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'links'            => 'Lesezeichen',
        'null'             => 'Null',
        'queries_per_hour' => 'Anfragen/Stunde',
        'size'             => 'Größe',
        'truncate'         => 'Leeren',
        'edittable'        => 'Bearbeiten',
        'tinyblob' =>
          '0-255 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'createuser'       => 'Neuer Benutzer',
        'realy'            => 'Wirklich',
        'register'         => 'Registrieren',
        'editentry'        => 'Bearbeiten',
        'shownewrow'       => 'Neue Zeile',
        'downloadfile'     => 'Herunterladen',
        'showdumptable'    => 'Exportieren',
        'mysql'            => 'mysql',
        'uploadsize'       => 'Upload Size',
        'showcreatetable'  => 'Tabelle erstellen',
        'select_all'       => 'Alle auswählen',
        'env'              => 'Env-Vars',
        'insert'           => 'Einfügen',
        'shownewtable'     => 'Datenbank',
        'showDir'          => 'Explorer',
        'rename '          => 'Rename ',
        'lang'             => 'de',
        'timebetweenposts' => 'Zeit zwischen Posts',
        'importfirefox'    => 'Firefox lesezeichen importieren',
        'datetime' =>
          '"1000-01-01 00:00:00" -"9999-12-31 23:59:59" Attributes: Global Only(YYYY-MM-DD hh:mm:ss) Default: NULL ["0000-00-00 00:00:00" if NOT NULL]',
        'over'               => 'über',
        'right_captcha_text' => 'Ok',
        'endtable'           => 'am ende',
        'newmessage'         => 'Neue Nachricht',
        'starttable'         => 'am Anfang',
        'htmlright'          => 'Html right',
        'columns'            => 'columns',
        'showtables'         => 'Tabellen',
        'sid'                => 'cf793dd5272145a48a9651794975f103',
        'varchar' =>
          'M=0-65,535 CharactersM=0-255 v5.0.3 Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'collation'            => 'Kollation',
        'blog'                 => 'Notitzen',
        'newmessagereleased'   => 'Nachricht erstellt',
        'editlinks'            => 'Bearbeiten',
        'style'                => 'Style',
        'sqleditor'            => 'Sql',
        'user_connections'     => 'Maximale Benutzer',
        'create'               => 'Erstellen',
        'readmore'             => 'mehr',
        'defaultaction'        => 'default action',
        'edittranslation'      => 'Übersetzen',
        'reg'                  => 'Registrieren',
        'fields'               => 'Spalten',
        'welcome'              => 'Willkommen',
        'default'              => 'Default',
        'type'                 => 'Type',
        'email'                => 'Email Adresse',
        'unselect_all'         => 'Auswahl aufheben',
        'editnavi'             => 'Navigation',
        'wrong_passwort_text'  => 'Das Passwort muss mindestens 6 zeichen lang sein',
        'new'                  => 'Neu',
        'importoperabookmarks' => 'Opera lesezeichen importiere',
        'rowsineffect'         => 'betroffene Datensätze',
        'details'              => 'Details',
        'change'               => 'Ändern',
        'headline'             => 'Überschrift',
        'password'             => 'Passwort',
        'inserttext'           => 'Text einfügen',
        'bit' =>
          'Binary. Display by [add zero or converting with BIN()]. M=1-64 Attributes: Prior to 5.03TINYINT(1) Synonym Default: NULL [0 if NOT NULL]',
        'homepagetitle'       => 'Homepage Titel',
        'failednotindatabase' => 'Nicht in Datenbank',
        'folderfirst'         => 'Verzeichnisse zuerst anzeigen.',
        'retry'               => 'Wiederhohlen',
        'extra'               => 'Extra',
        'showsqlsearch'       => 'Suchen',
        'float' =>
          'Min=+/-1.175E-38 Max=+/-3.403E+38 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
        'explorer'       => 'Explorer',
        'edittableprops' => 'Bearbeiten',
        'servername'     => 'Server-Name',
        'sub_part'       => 'sub_part',
        'int' =>
          '-/+2.147E+9 [0 to 4.294E+9] AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'fulltext'    => 'Suchen',
        'addfulltext' => 'Add Fulltext',
        'limit'       => 'Limit',
        'bigint' =>
          '-/+9.223E+18 [0 to 18.45E+18] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'showeditindex' => 'Index erstellen',
        'tinyint' =>
          'TINYINT -128 TO 127  [0 to 255 if UNSIGNED],Attributes: AUTO_INCREMENT  UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'length'                   => 'länge',
        'changeautoincrementvalue' => 'Auto Increment Wert',
        'createnewtable'           => 'Neue Tabelle',
        'saveprofile'              => 'Profile',
        'binary' =>
          'M=0-255 bytes, FIXED. Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'admin' => 'Admin',
        'longtext' =>
          '0-4,294,967,295 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'newfileadded'        => 'Datei erstellt',
        'editmysqluserrights' => 'Benutzerrechte',
        'showrights'          => 'Rechte',
        'selected'            => 'Alle auswählen',
        'key_name'            => 'Key Name',
        'newentry'            => 'Neuer Eintrag',
        't_regtext'           => 'Registrieren',
        'test'                => 'test',
        'choosefile'          => 'Datei auswählen',
        'login'               => 'Anmelden',
        'gbook_body'          => 'Erstelle Deine Nachricht.',
        'addnews'             => 'Neue Nachricht',
        'right_passwort_text' => 'Ok',
        'changecharset'       => 'Zeichensatz',
        'contakt'             => 'Kontakt',
        'regmessage'        => 'Sie erhalten diese Email weil Sie sich auf ...  registriert haben.',
        'databases'         => 'Datenbanken',
        'insertname'        => 'Name angeben',
        'analyzetable'      => 'Analysieren',
        'saveedittable'     => 'Speichern',
        'showprofile'       => 'Profile',
        'newpass'           => 'Neues Passwort',
        'showdumpdatabase'  => 'Exportieren',
        'MoveTreeViewEntry' => 'Verschieben',
        'drop_database'     => 'Datenbank löschen',
        'decimal' =>
          'Stored as string Max Range = DOUBLE rangeFixed point vs. DOUBLE float Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
        'set' =>
          '("A1","A2",...) Column is 0 or more values in list of 1-64 members Attributes: CHARACTER SET Default: NULL ["" if NOT NULL]',
        'save'          => 'Speichern',
        'showvariables' => 'Variablen',
        'double' =>
          'Min=+/-2.225E-308 Max=+/-1.798E+308 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
        'optimizetable' => 'Optimieren',
        'smallint' =>
          '-32,768 to 32,767 [0 to 65,535] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'floodtext'           => 'nicht so oft posten',
        'documentroot'        => 'Document Root',
        'saveedit'            => 'Speichern',
        'edit'                => 'Bearbeiten',
        'nomail'              => 'Keine Email Adresse angegeben.',
        'seq_in_index'        => 'seq_in_index',
        'done'                => 'fertig',
        'logout'              => 'Abmelden',
        'catslist'            => 'Kategorien',
        'preview'             => 'Vorschau',
        'right_username_text' => 'Ok',
        'wrong_database_name' => 'Falscher Datenbank Name',
        'database'            => 'Datenbank',
        'showcreateuser'      => 'Benutzer',
        'maxuploadsize'       => 'Maximale Datei Größe',
        'reply'               => 'Antworten',
        'longblob' =>
          '0-4,294,967,295 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'time' =>
          '"-838:59:59" - "838:59:59" Attributes: Global Only(hh:mm:ss) Default: NULL["00:00:00" if NOT NULL]',
        'newcol' => 'Neue Zeile',
        'char' =>
          'M=0-255 Characters, FIXED.Right padded with spaces. Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'mediumtext' =>
          '0-16,777,215 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'showprocesslist'   => 'Processe',
        'failedinvalidcode' => 'Falscher Code',
        'sql'               => 'SQL',
        'editmessage'       => 'Bearbeiten',
        'translate'         => 'Übersetzen',
        'news'              => 'Blog',
        'mediumblob' =>
          '0-16,777,215 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]'
    },
    'en' => {
        'createdatabase'     => 'New Database',
        'wrong_captcha_text' => 'wrong_captcha_text',
        'maxlength'          => 'Maxlength',
        'changeengine'       => 'Change Engine',
        'newsperpage'        => 'newsperpage',
        'createindex'        => 'New Index',
        'blob' =>
          '0-65,535 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'changecurrentdb'     => 'Server',
        'createtable'         => 'New Table',
        'repair'              => 'Repair',
        'indexover'           => 'Index over',
        'next'                => 'Next',
        'field'               => 'Field',
        'checkformsddfsds'    => 'true',
        'showcreatedatabase'  => 'New Database',
        'street'              => 'street',
        'activates'           => 'Activates',
        'bookmarks'           => 'bookmarks',
        'phone'               => 'Phone',
        'addindex'            => 'Create Index',
        'addunique'           => 'Unique Index hinzufügen',
        'right_database_name' => 'right_database_name',
        'newfolder'           => 'New Folder',
        'showdatabases'       => 'Databases',
        'enum' =>
          'Column is exactly 1 of 1-65,535 values Attributes: CHARACTER SET Default: NULL [1st value if NOT NULL]',
        'username'                => 'Username',
        'make'                    => 'Make',
        'packed'                  => 'packed',
        'daten'                   => 'Data',
        'codenotcheckedfileerror' => '',
        'properties'              => 'properties',
        'renametable'             => 'Rename Table',
        'chars'                   => 'Chars',
        'tinytext' =>
          '0-255 Characters Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'speichern'        => 'Speichern',
        'saverights'       => 'Rights',
        'repairtable'      => 'Repair Table',
        'newTreeViewEntry' => 'Bookmarks',
        'year'    => '1900 - 2155 Attributes: Global Only(YYYY) Default: NULL["0000" if NOT NULL]',
        'profile' => 'Profile',
        'sort'    => 'Sort',
        'editindex'     => 'Index bearbeiten',
        'rows'          => 'Rows',
        'addNews'       => 'New Message',
        'user'          => 'Username',
        'after'         => 'after',
        'rights'        => 'Rights',
        'news_pro_page' => 'Pages/Sites',
        'varbinary' =>
          '0-65,535 bytesM=0-255 v5.0.3 Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'uploadsize'       => 'Upload Size',
        'showcreatetable'  => 'New Table',
        'showdumptable'    => 'Export',
        'mysql'            => 'mysql',
        'insert'           => 'Insert',
        'select_all'       => 'Select All',
        'env'              => 'env',
        'rename '          => 'Rename ',
        'shownewtable'     => 'Database',
        'null'             => 'Null',
        'links'            => 'links',
        'queries_per_hour' => 'QUERIES/HOUR',
        'downEntry'        => 'Bookmarks',
        'size'             => 'Size',
        'edittable'        => 'Database',
        'tinyblob' =>
          '0-255 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'createuser'           => 'Create User',
        'truncate'             => 'Truncate',
        'realy'                => 'Realy',
        'register'             => 'Register',
        'editentry'            => 'Edit Entry',
        'downloadfile'         => 'Download',
        'shownewrow'           => 'New Row',
        'host'                 => 'Host',
        'body'                 => 'Body',
        'searchdatabase'       => 'Search',
        'answers'              => 'answers',
        'search'               => 'Search',
        ''                     => 'news',
        'savetranslate'        => 'Save Translate',
        'city'                 => 'city',
        'uploads'              => 'Uploads',
        'settings'             => 'settings',
        'exportoperabookmarks' => 'Export Opera Bookmarks',
        'attribute'            => 'Attribute',
        'show'                 => 'Show',
        'uploadpath'           => 'uploadpath',
        'execsql'              => 'Sql',
        'searchhelptopic'      => 'Help',
        'wrong_username_text' =>
          'The Username must be at least 3 characters in length and can only contain letters or digits.',
        'pass'                => 'Pass',
        'rebuild'             => 'rebuild',
        'deleteentry'         => 'Table',
        'comment'             => 'Comment',
        'trash'               => 'trash',
        'wrongpass'           => 'wrongpass',
        'uploadchmod'         => 'Upload Chmod',
        'showchangecurrentdb' => 'Server',
        'sqlsearch'           => 'Search',
        'firstname'           => 'Firstname',
        'index_type'          => 'index_type',
        'addtranslation'      => 'Add Translation',
        'showtabledetails'    => 'Details',
        'insertafter'         => 'After',
        'processlist'         => 'Processes',
        'showusers'           => 'User',
        'rename'              => 'Rename',
        'mediumint' =>
          '-8,388,608 to 8,388,607 [0 to 16,777,215] Attributes:  AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'userprofile'          => 'User Profile',
        'postcode'             => 'Postcode',
        'navigation'           => 'navigation',
        'table'                => 'Table',
        'connections_per_hour' => 'Connections / HOUR',
        'non_unique'           => 'non_unique',
        'updates_per_hour'     => 'Updates / HOUR',
        'addprimarykey'        => 'AddPrimaryKey',
        'dropcolumn'           => 'Drop Column',
        'mailsubject'          => 'Subject',
        'column_name'          => 'column_name',
        'showtable'            => 'Table',
        'timestamp' =>
          '19700101000000 -2037+ Attributes: Global Only(YYYYMMDDhhmmss) Default: Current Date &amp; Time',
        'links_pro_page' => 'Links/Page',
        'connect'        => 'Connect',
        'back'           => 'back',
        'impressum'      => 'Impressum',
        'editTreeview'   => 'Edit',
        'gbook'          => 'gbook',
        'cardinality'    => 'cardinality',
        'droptable'      => 'Tables',
        'showsqleditor'  => 'Sql',
        'text' => '0-65,535 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'shownewentry'   => 'New Entry',
        'puplisher'      => 'Puplisher',
        'dropdatabase'   => 'Databases',
        'exportdatabase' => 'Database',
        'regexp'         => 'Regular Expression',
        'date' =>
          '"1000-01-01" - "9999-12-31" Attributes: Global Only(YYYY-MM-DD) Default: NULL["0000-00-00" if NOT NULL]',
        'name'       => 'Name',
        'cookiepath' => 'cookiepath',
        'delete'     => 'Delete',
        'optimize'   => 'Optimize',
        'export'     => 'Export',
        'test'       => 'test',
        'choosefile' => 'Choose File',
        'login'      => 'Login',
        'admin'      => 'admin',
        'longtext' =>
          '0-4,294,967,295 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'newfileadded'        => 'Done',
        'editmysqluserrights' => 'Rights',
        'showrights'          => 'Rights',
        'selected'            => 'Select all',
        'newentry'            => 'New Entry',
        't_regtext'           => 'Register',
        'key_name'            => 'key_name',
        'showprofile'         => 'Profile',
        'decimal' =>
          'Stored as string Max Range = DOUBLE rangeFixed point vs. DOUBLE float Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
        'newpass'           => 'New Password',
        'MoveTreeViewEntry' => 'move',
        'drop_database'     => 'Drop Database',
        'showdumpdatabase'  => 'Export',
        'showvariables'     => 'Variables',
        'set' =>
          '("A1","A2",...) Column is 0 or more values in list of 1-64 members Attributes: CHARACTER SET Default: NULL ["" if NOT NULL]',
        'save' => 'Save',
        'double' =>
          'Min=+/-2.225E-308 Max=+/-1.798E+308 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
        'gbook_body'          => 'Write your comment ...',
        'regmessage'          => 'Registration Email',
        'contakt'             => 'Contakt',
        'databases'           => 'Databases',
        'right_passwort_text' => 'Ok',
        'changecharset'       => 'Change Charset',
        'saveedittable'       => 'Table',
        'insertname'          => 'Name',
        'analyzetable'        => 'Analyze Table',
        'nomail'              => 'No Email Adresss given.',
        'seq_in_index'        => 'seq_in_index',
        'done'                => 'Done',
        'logout'              => 'Logout',
        'catslist'            => 'catslist',
        'right_username_text' => 'Ok',
        'preview'             => 'Preview',
        'optimizetable'       => 'Optimize Table',
        'floodtext'           => 'Don’t post so often.',
        'saveedit'            => 'Save',
        'edit'                => 'Edit',
        'documentroot'        => 'Document Root',
        'newcol'              => 'New Column',
        'char' =>
          'M=0-255 Characters, FIXED.Right padded with spaces. Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'mediumtext' =>
          '0-16,777,215 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'failedinvalidcode' => 'Failed invalid code',
        'sql'               => 'SQL',
        'showprocesslist'   => 'Processlist',
        'editmessage'       => 'Edit Message',
        'news'              => 'Blog',
        'upEntry'           => 'Bookmarks',
        'mediumblob' =>
          '0-16,777,215 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'translate'           => 'Translate',
        'wrong_database_name' => 'wrong_database_name',
        'database'            => 'Database',
        'maxuploadsize'       => 'maxuploadsize',
        'longblob' =>
          '0-4,294,967,295 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'reply'          => 'Reply',
        'showcreateuser' => 'New User',
        'time' =>
          '"-838:59:59" - "838:59:59" Attributes: Global Only(hh:mm:ss) Default: NULL["00:00:00" if NOT NULL]',
        'permalink' => 'permalink',
        'varchar' =>
          'M=0-65,535 CharactersM=0-255 v5.0.3 Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
        'collation'     => 'Collation',
        'importfirefox' => 'Import Firefox',
        'datetime' =>
          '"1000-01-01 00:00:00" -"9999-12-31 23:59:59" Attributes: Global Only(YYYY-MM-DD hh:mm:ss) Default: NULL ["0000-00-00 00:00:00" if NOT NULL]',
        'lang'                 => 'en',
        'timebetweenposts'     => 'Time between Posts',
        'right_captcha_text'   => 'Ok',
        'over'                 => 'over',
        'newmessage'           => 'New Message',
        'endtable'             => 'at end',
        'showtables'           => 'Tables',
        'columns'              => 'columns',
        'starttable'           => 'at start',
        'htmlright'            => 'htmlright',
        'edittranslation'      => 'edittranslation',
        'blog'                 => 'Blog',
        'sqleditor'            => 'Sql',
        'style'                => 'style',
        'user_connections'     => 'Max User',
        'newmessagereleased'   => 'New message released',
        'editlinks'            => 'Edit Bookmarks',
        'readmore'             => 'More',
        'defaultaction'        => 'defaultaction',
        'create'               => 'Create',
        'importoperabookmarks' => 'Import Opera Bookmarks',
        'rowsineffect'         => 'rows in effect',
        'details'              => 'Details',
        'change'               => 'Ändern',
        'headline'             => 'Headline',
        'password'             => 'Password',
        'homepagetitle'        => 'Homepage Title',
        'bit' =>
          'Binary. Display by [add zero or converting with BIN()]. M=1-64 Attributes: Prior to 5.03TINYINT(1) Synonym Default: NULL [0 if NOT NULL]',
        'inserttext'          => 'Insert Text',
        'folderfirst'         => 'Folder First',
        'failednotindatabase' => 'Failed: not in database',
        'reg'                 => 'Register',
        'fields'              => 'Fields',
        'type'                => 'Type',
        'email'               => 'Email',
        'welcome'             => 'Welcome',
        'default'             => 'Default',
        'unselect_all'        => 'Unselect',
        'wrong_passwort_text' => 'The password must be at least 6 characters in length.',
        'editnavi'            => 'Navigation',
        'new'                 => 'New',
        'addfulltext'         => 'Add Fulltext',
        'int' =>
          '-/+2.147E+9 [0 to 4.294E+9] AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'fulltext' => 'Search',
        'tinyint' =>
          'TINYINT -128 TO 127  [0 to 255 if UNSIGNED],Attributes: AUTO_INCREMENT  UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'length'                   => 'LENGTH',
        'changeautoincrementvalue' => 'Auto Increment Value',
        'createnewtable'           => 'New Table',
        'showeditindex'            => 'New Index',
        'limit'                    => 'Limit',
        'bigint' =>
          '-/+9.223E+18 [0 to 18.45E+18] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
        'saveprofile' => 'Profile',
        'binary' =>
          'M=0-255 bytes, FIXED. Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
        'float' =>
          'Min=+/-1.175E-38 Max=+/-3.403E+38 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
        'extra'          => 'Extra',
        'retry'          => 'retry',
        'showsqlsearch'  => 'Search in DB',
        'explorer'       => 'Explorer',
        'edittableprops' => 'Table',
        'servername'     => 'servername',
        'sub_part'       => 'sub_part'
    }
};
$lang = $VAR1;
