[previewHeadline]
<div id="ptitel" ><b></b></div>
[/previewHeadline]
[previewBody]
<a name="name" id="headline2" ></a><div id="pbody"></div>
<br/><br/>
[/previewBody]
[editor]
<div class="ShowTables" style="padding-bottom:1%;margin-top:1.5em;" >
<form name="postmodify"  method="post"  enctype="multipart/form-data" onsubmit="submitForm(this,'[action/]','[action/]');return false;" accept-charset="UTF-8">
<table class="editor" width="100%" >
<tr>
<td>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="100%">
<tr>
<td colspan="2" align="left" sid="buttons">[buttons/]</td>
</tr>
<tr>
<td width="*"><a name="winedit"></a><input name="headline" id="title" value="[headline/]" type="text" style="width:100%;"/>
</td><td align="right">[catlist/][atemp/]</td>
</tr>
<tr>
<td align="center" colspan="2">
<textarea rows="10" class="txt" name="message" id="txt" style="width:100%;">[body/]</textarea>
<script language="JavaScript1.5" type="text/javascript">blogThis();</script>
</td>
</tr>
<tr><td align="left" colspan="2">
<input  name="action" value="[action/]" style="display:none;"/>
<input  name="thread" value="[thread/]" style="display:none;"/>
<input  name="reply" value="[reply/]" style="display:none;"/>
[attach/]
</td>
</tr>
 <tr>
<td align="right" colspan="2">
<input type="submit" name="submit" onclick="act ='[tr=preview/]';" align="middle" alt="preview" value="[tr=preview/]" title="[tr=preview/]"/>&#160;
<input type="submit" name="submit" style="cursor:pointer;" align="middle" value="[tr=save/]" title="[tr=save/]" onclick="act ='[tr=save/]'" />
</td>
</tr>
</table>
</td>
</tr>
</table>
</form>
</div>
[/editor]
