$VAR1 = [
    {
     'accesskey'   => '',
     'onfocus'     => '',
     'dump'        => undef,
     'class'       => '',
     'onmouseout'  => '',
     'onmousedown' => '',
     'href' =>
       'javascript:requestURI(\'cgi-bin/mysql.pl?action=EditFile&name=\'+cAction,\'EditFile\',\'EditFile\');',
     'onkeypress'  => '',
     'onblur'      => '',
     'type'        => '',
     'folder'      => undef,
     'rev'         => '',
     'rid'         => 1,
     'onmouseover' => '',
     'onkeyup'     => '',
     'ondblclick'  => '',
     'right'       => '5',
     'title'       => '',
     'lang'        => '',
     'subtree'     => [],
     'name'        => '',
     'style'       => '',
     'onkeydown'   => '',
     'coords'      => '',
     '1'           => undef,
     'charset'     => '',
     'onclick'     => '',
     'dir'         => '',
     'text'        => 'Edit File',
     'action'      => undef,
     ''            => 'save',
     'hreflang'    => '',
     'shape'       => '',
     'sid'         => 'cf793dd5272145a48a9651794975f103',
     'onmousemove' => '',
     'id'          => 'a1',
     'rel'         => '',
     'tabindex'    => '',
     'target'      => '',
     'onmouseup'   => ''
    },
    {
     'id'          => 'a2',
     'onmousemove' => '',
     'shape'       => '',
     'sid'         => 'cf793dd5272145a48a9651794975f103',
     'onmouseup'   => '',
     'target'      => '',
     'tabindex'    => '',
     'rel'         => '',
     'charset'     => '',
     '1'           => undef,
     'coords'      => '',
     'onkeydown'   => '',
     ''            => 'save',
     'hreflang'    => '',
     'action'      => undef,
     'text'        => 'Cms',
     'onclick'     => '',
     'dir'         => '',
     'right'       => '',
     'title'       => '',
     'ondblclick'  => '',
     'onkeyup'     => '',
     'onmouseover' => '',
     'name'        => '',
     'style'       => '',
     'subtree'     => [],
     'lang'        => '',
     'onmousedown' => '',
     'onmouseout'  => '',
     'href'        => 'cms.html',
     'dump'        => undef,
     'accesskey'   => '',
     'onfocus'     => '',
     'rid'         => 2,
     'rev'         => '',
     'onkeypress'  => '',
     'folder'      => undef,
     'onblur'      => '',
     'type'        => ''
    }
];
@TreeView = $VAR1;
